diff Core/HttpServer/EmbeddedResourceHttpHandler.cpp @ 50:a15e90e5d6fc

rename in code
author Sebastien Jodogne <s.jodogne@gmail.com>
date Wed, 05 Sep 2012 15:50:12 +0200
parents 9be852ad33d2
children c996319e90bc
line wrap: on
line diff
--- a/Core/HttpServer/EmbeddedResourceHttpHandler.cpp	Wed Sep 05 15:38:08 2012 +0200
+++ b/Core/HttpServer/EmbeddedResourceHttpHandler.cpp	Wed Sep 05 15:50:12 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palantir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -20,12 +20,12 @@
 
 #include "EmbeddedResourceHttpHandler.h"
 
-#include "../PalantirException.h"
+#include "../PalanthirException.h"
 
 #include <stdio.h>
 
 
-namespace Palantir
+namespace Palanthir
 {
   EmbeddedResourceHttpHandler::EmbeddedResourceHttpHandler(
     const std::string& baseUri,
@@ -65,9 +65,9 @@
       size_t size = EmbeddedResources::GetDirectoryResourceSize(resourceId_, resourcePath.c_str());
       output.AnswerBufferWithContentType(buffer, size, contentType);
     }
-    catch (PalantirException& e)
+    catch (PalanthirException& e)
     {
-      output.SendHeader(Palantir_HttpStatus_404_NotFound);
+      output.SendHeader(Palanthir_HttpStatus_404_NotFound);
     }
   } 
 }
@@ -1,5 +1,5 @@
 /**
- * Palantir - A Lightweight, RESTful DICOM Store
+ * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium